@@ -23,17 +23,17 @@ from aliyunsdkedas.endpoint import endpoint_data
 class DeleteEcuRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'DeleteEcu','edas')
+		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'DeleteEcu','Edas')
 		self.set_uri_pattern('/pop/v5/resource/delete_ecu')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_EcuId(self):
+	def get_EcuId(self): # String
 		return self.get_query_params().get('EcuId')
 
-	def set_EcuId(self,EcuId):
-		self.add_query_param('EcuId',EcuId)
\ No newline at end of file
+	def set_EcuId(self, EcuId):  # String
+		self.add_query_param('EcuId', EcuId)
