@@ -23,17 +23,17 @@ from aliyunsdkedas.endpoint import endpoint_data
 class DeleteServiceGroupRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'DeleteServiceGroup','edas')
+		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'DeleteServiceGroup','Edas')
 		self.set_uri_pattern('/pop/v5/service/serviceGroups')
 		self.set_method('DELETE')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_GroupId(self):
+	def get_GroupId(self): # String
 		return self.get_query_params().get('GroupId')
 
-	def set_GroupId(self,GroupId):
-		self.add_query_param('GroupId',GroupId)
\ No newline at end of file
+	def set_GroupId(self, GroupId):  # String
+		self.add_query_param('GroupId', GroupId)
