@@ -23,17 +23,17 @@ from aliyunsdkedas.endpoint import endpoint_data
 class DeleteSwimmingLaneRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'DeleteSwimmingLane','edas')
+		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'DeleteSwimmingLane','Edas')
 		self.set_uri_pattern('/pop/v5/trafficmgnt/swimming_lanes')
 		self.set_method('DELETE')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_LaneId(self):
+	def get_LaneId(self): # Long
 		return self.get_query_params().get('LaneId')
 
-	def set_LaneId(self,LaneId):
-		self.add_query_param('LaneId',LaneId)
\ No newline at end of file
+	def set_LaneId(self, LaneId):  # Long
+		self.add_query_param('LaneId', LaneId)
