@@ -23,17 +23,17 @@ from aliyunsdkedas.endpoint import endpoint_data
 class GetSecureTokenRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'GetSecureToken','edas')
+		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'GetSecureToken','Edas')
 		self.set_uri_pattern('/pop/v5/secure_token')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_NamespaceId(self):
+	def get_NamespaceId(self): # String
 		return self.get_query_params().get('NamespaceId')
 
-	def set_NamespaceId(self,NamespaceId):
-		self.add_query_param('NamespaceId',NamespaceId)
\ No newline at end of file
+	def set_NamespaceId(self, NamespaceId):  # String
+		self.add_query_param('NamespaceId', NamespaceId)
