@@ -23,17 +23,17 @@ from aliyunsdkedas.endpoint import endpoint_data
 class ListConsumedServicesRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'ListConsumedServices','edas')
+		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'ListConsumedServices','Edas')
 		self.set_uri_pattern('/pop/v5/service/listConsumedServices')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AppId(self):
+	def get_AppId(self): # String
 		return self.get_query_params().get('AppId')
 
-	def set_AppId(self,AppId):
-		self.add_query_param('AppId',AppId)
\ No newline at end of file
+	def set_AppId(self, AppId):  # String
+		self.add_query_param('AppId', AppId)
