@@ -23,10 +23,27 @@ from aliyunsdkedas.endpoint import endpoint_data
 class ListSlbRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'ListSlb','edas')
+		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'ListSlb','Edas')
 		self.set_uri_pattern('/pop/v5/slb_list')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_SlbType(self): # String
+		return self.get_query_params().get('SlbType')
+
+	def set_SlbType(self, SlbType):  # String
+		self.add_query_param('SlbType', SlbType)
+	def get_VpcId(self): # String
+		return self.get_query_params().get('VpcId')
+
+	def set_VpcId(self, VpcId):  # String
+		self.add_query_param('VpcId', VpcId)
+	def get_AddressType(self): # String
+		return self.get_query_params().get('AddressType')
+
+	def set_AddressType(self, AddressType):  # String
+		self.add_query_param('AddressType', AddressType)
