@@ -23,10 +23,12 @@ from aliyunsdkedas.endpoint import endpoint_data
 class ListVpcRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'ListVpc','edas')
+		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'ListVpc','Edas')
 		self.set_uri_pattern('/pop/v5/vpc_list')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
