@@ -23,17 +23,17 @@ from aliyunsdkedas.endpoint import endpoint_data
 class QueryEccInfoRequest(RoaRequest):
 
 	def __init__(self):
-		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'QueryEccInfo','edas')
+		RoaRequest.__init__(self, 'Edas', '2017-08-01', 'QueryEccInfo','Edas')
 		self.set_uri_pattern('/pop/v5/ecc')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_EccId(self):
+	def get_EccId(self): # String
 		return self.get_query_params().get('EccId')
 
-	def set_EccId(self,EccId):
-		self.add_query_param('EccId',EccId)
\ No newline at end of file
+	def set_EccId(self, EccId):  # String
+		self.add_query_param('EccId', EccId)
